const path = require('path');
const webpack = require('webpack');
const autoprefixer = require('autoprefixer');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
	entry: './src/index.js',
	devtool: 'source-map',
	output: {
		path: path.join(__dirname, "lib"),
		filename: 'hemsworth.js',
		library: 'hemsworth',
		libraryTarget: 'umd',
		umdNamedDefine: true
	},
	module: {
		loaders: [
			{
				test: /.jsx?$/,
				exclude: [
					/node_modules/, /vendor/
				],
				loader: 'babel',
				query: {
					presets: [
						'es2015', 'react', 'stage-1'
					],
					plugins: ['babel-plugin-add-module-exports']
				}
			}, {
				test: /(\.scss|\.css)$/,
				loader: ExtractTextPlugin.extract('style', 'css?sourceMap&modules&importLoaders=1&localIdentName=[name]__[local]___[hash:bas' +
						'e64:5]!postcss!sass?sourceMap')
			}
		]
	},
	externals: {
		"react": "react"
	},
	resolve: {
		root: path.resolve('./src'),
		extensions: ['', '.js']
	},
	postcss: [autoprefixer],
	plugins: [
		new ExtractTextPlugin('react-toolbox.css', {allChunks: true}),
		new webpack.HotModuleReplacementPlugin(),
		new webpack.NoErrorsPlugin(),
		new webpack.DefinePlugin({'process.env.NODE_ENV': JSON.stringify('development')})
	]
}
